import { Application, Container } from "starspot-core";
import Resource from "./resource";
import JSONAPI from "./json-api";
import Operation, { OperationOptions, CallbackTarget } from "./operation";
export interface ConcreteOperation {
    new (options: {}): Operation;
}
export interface RequestParameters {
    /** The HTTP request. */
    request: Application.Request;
    /** The controller action used to process this request. */
    action: string;
    /** The name of the controller processing this request. */
    controllerName: string;
    /** Params extracted from URL segments, such as `id` **/
    urlParams: {
        [key: string]: any;
    };
    /** Method that returns a promise that resolves to a JSON API document. */
    json(): Promise<JSONAPI.Document>;
}
export default class RequestParser {
    container: Container;
    params: RequestParameters;
    private operations;
    private json;
    private target;
    constructor(params: RequestParameters, container: Container, target: CallbackTarget);
    parse(): Promise<Operation[]>;
    processIndex(): void;
    processShow(): void;
    processCreate(): void;
    processUpdate(): void;
    op(Op: ConcreteOperation, options: OperationOptions): void;
    readonly resource: typeof Resource;
}
